@@ -45,7 +45,7 @@ class Audit:
     good = [x for x in results if len(x.get_vulnerabilities()) == 0]
     bad = [x for x in results if len(x.get_vulnerabilities()) > 0]
 
-    if len(good) != 0:
+    if (len(good) != 0 and not self._quiet):
       print()
       print("Non-Vulnerable Dependencies")
       print()
